@@ -1,15 +1,15 @@
 """Embed module."""
 
-from typing import Optional
+from typing import Callable, Optional
 
+import jax
 import jax.numpy as jnp
 
-from .. import initializers
-from ..core import Module
+from ..core import ParameterModule
 from ..core.rng import KeyArray, next_rng_key
 
 
-class Embed(Module):
+class Embed(ParameterModule):
     """Embed module maps integer values to real vectors.
     The embedded vectors are trainable.
     """
@@ -22,7 +22,7 @@ class Embed(Module):
         self,
         vocab_size: int,
         embed_dim: int,
-        w_init: Optional[initializers.Initializer] = None,
+        w_init: Optional[Callable] = None,
         *,
         rng_key: Optional[KeyArray] = None,
         name: Optional[str] = None
@@ -44,12 +44,12 @@ class Embed(Module):
         shape = [vocab_size, embed_dim]
 
         if w_init is None:
-            w_init = initializers.truncated_normal()
+            w_init = jax.nn.initializers.normal()
 
         if rng_key is None:
             rng_key = next_rng_key()
 
-        self.register_parameter("weight", w_init(shape, jnp.float32, rng_key))
+        self.weight = w_init(rng_key, shape)
 
     def __call__(self, x: jnp.ndarray):
         """Return embedded vectors indexed by ``x``."""
@@ -57,4 +57,4 @@ class Embed(Module):
 
     def __repr__(self):
         info = {"vocab_size": self.vocab_size, "embed_dim": self.embed_dim}
-        return super()._repr(info)
+        return self._repr(info)
