@@ -10,18 +10,17 @@
 #     2. We can input `rng_key` to seed the value of scale/offset parameters.
 
 import collections
-from typing import Optional, Sequence, Union
+from typing import Callable, Optional, Sequence, Union
 
 import jax
 import jax.numpy as jnp
 import numpy as np
 
-from .. import initializers
-from ..core import Module
+from ..core import ParameterModule
 from ..core.rng import KeyArray, next_rng_key
 
 
-class LayerNorm(Module):
+class LayerNorm(ParameterModule):
     """LayerNorm module.
     See: https://arxiv.org/abs/1607.06450.
     """
@@ -36,12 +35,13 @@ class LayerNorm(Module):
         create_scale: bool,
         create_offset: bool,
         eps: float = 1e-5,
-        scale_init: Optional[initializers.Initializer] = None,
-        offset_init: Optional[initializers.Initializer] = None,
+        scale_init: Optional[Callable] = None,
+        offset_init: Optional[Callable] = None,
         *,
         rng_key: Optional[KeyArray] = None,
         name: Optional[str] = None,
     ):
+        jax.nn.initializers
         """Constructs a LayerNorm module.
 
         Arguments:
@@ -78,23 +78,19 @@ class LayerNorm(Module):
         self.eps = eps
         self.create_scale = create_scale
         self.create_offset = create_offset
-        self.scale_init = scale_init or initializers.ones
-        self.offset_init = offset_init or initializers.zeros
+        self.scale_init = scale_init or jax.nn.initializers.ones
+        self.offset_init = offset_init or jax.nn.initializers.zeros
         self.num_channels = num_channels
 
         param_shape = [num_channels]
         rng_key = next_rng_key() if rng_key is None else rng_key
         rng1, rng2 = jax.random.split(rng_key)
         if create_scale:
-            self.register_parameter(
-                "scale", self.scale_init(param_shape, jnp.float32, rng1)
-            )
+            self.scale = self.scale_init(rng1, param_shape)
         else:
             self.scale = None
         if create_offset:
-            self.register_parameter(
-                "offset", self.offset_init(param_shape, jnp.float32, rng2)
-            )
+            self.offset = self.offset_init(rng2, param_shape)
         else:
             self.offset = None
 
@@ -160,4 +156,4 @@ class LayerNorm(Module):
             "create_scale": self.create_scale,
             "create_offset": self.create_offset,
         }
-        return super()._repr(info)
+        return self._repr(info)
