@@ -56,7 +56,7 @@ class Linear(ParameterModule):
         if self.with_bias:
             self.bias = b_init(rng_key_b, (out_dim,))
 
-    def __call__(self, x: np.ndarray) -> jnp.ndarray:
+    def __call__(self, x: jnp.ndarray) -> jnp.ndarray:
         """Applies a linear transformation to the inputs along the last dimension.
 
         Arguments:
