@@ -1,12 +1,12 @@
 """Experimental API"""
 
 
-from pax._src.core import Flattener, LazyModule
+from pax._src.core import Flattener, LazyModule, mutable
 from pax._src.utils import (
     apply_scaled_gradients,
     default_mp_policy,
-    save_weights_to_dict,
     load_weights_from_dict,
+    save_weights_to_dict,
 )
 
 from . import graph
@@ -18,5 +18,6 @@ __all__ = (
     "graph",
     "LazyModule",
     "load_weights_from_dict",
+    "mutable",
     "save_weights_to_dict",
 )
